package org.openscm.kundo.strategy

/*
 * Copyright (C) 2008 The Ultimate People Company Ltd ("UPCO").
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import org.openscm.kundo.common.logging.SimpleLogger
import org.openscm.kundo.plugins.context.BuildContext

/**
 * AbstractProjectStrategy
 * @author <a href="mailto:ben.leedham@upco.co.uk">Ben Leedham</a>
 * @version 1.0.0
 * 
 * Description: An abstraction of the project strategy. 
 * 
 */
public abstract class AbstractProjectStrategy implements ProjectStrategy {
	
	
	/** Logger instance **/
	protected final SimpleLogger log
	/** AntBuilder instance **/
	protected AntBuilder ant
	/** BuildContext instance **/
	protected BuildContext buildContext

	/**
	 * Constructor sets ant instance
	 * @param ant			AntBuilder instance
	 * @param buildContext	BuildContext instance
	 */
	 AbstractProjectStrategy( AntBuilder ant, BuildContext buildContext ) {
		this.ant = ant
		this.buildContext = buildContext
		log = SimpleLogger.getInstance( ant )
	}
	
	abstract void doCheck()
	
	void doExecute(){
		 doCheck()
		 doProject()
	}

}